package jp.jsworld.SpModeMailWatcher;

import android.app.Notification;
import android.app.NotificationManager;
import android.content.Intent;
import android.os.Bundle;
import android.preference.CheckBoxPreference;
import android.preference.EditTextPreference;
import android.preference.ListPreference;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceScreen;
import android.preference.RingtonePreference;
import android.preference.Preference.OnPreferenceChangeListener;
import android.preference.Preference.OnPreferenceClickListener;

/**
 * SPモードメール監視の各種設定を行うメインのアクティビティです。
 *
 * @version 1.3.1
 * @author jun shiozaki
 *
 *         【ver. 1.3.1 2012/07/29】<br>
 *         ・設定画面をメイン画面から切り離しました。
 *
 *         【ver. 1.3.0 2012/07/28】<br>
 *         ・スクリーン ON で鳴動を停止する設定を追加<br>
 *         ・未受信メール通知中にメッセージを表示するかの設定を追加<br>
 *         ・インフォメーションの表示を追加<br>
 *
 *         【ver. 1.2.6 2012/07/08】<br>
 *         ・新着メールを受信して未受信メールの通知を無視する時間を設定する機能を追加<br>
 *         ・着信音再生時間に"１曲"を追加<br>
 *         着信音再生テキストは SettingReader.getNoticeSoundPlayTimeText() を使用する。<br>
 *
 *         【ver. 1.2.5 2012/06/30】<br>
 *         ・LEDフラグのOFFでLEDの点滅を停止できる昨日を追加<br>
 *
 *         【ver. 1.2.4 2012/06/23】<br>
 *         ・鳴動時間の設定を削除<br>
 *         ・着信音の再生時間の設定を追加<br>
 *         ・バイブレーターの振動時間を追加<br>
 *
 *         【ver. 1.2.0 2012/06/03】<br>
 *         ・通知LEDのプリファレンスコントロールの処理を追加<br>
 *
 *         【ver. 1.1.0 2012/05/03】<br>
 *         ・SPモードメールを受信するメーラーのプリファレンスコントロールの処理を追加<br>
 *         ・CommuniCase 使用時のSPモードメールアカウントのプリファレンスコントロールの処理を追加<br>
 */
public class SettingActivity extends PreferenceActivity {

    protected SettingReader sr = null;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        sr = new SettingReader(this);

        // xml レイアウトの読み込み
        this.addPreferencesFromResource(R.xml.pref);

        // インフォメーションプリファレンスコントロールの設定をします。
        PreferenceScreen scrInfomation = (PreferenceScreen) findPreference(getText(R.string.scr_information));
        scrInfomation
                .setOnPreferenceClickListener(new OnPreferenceClickListener() {
                    public boolean onPreferenceClick(Preference pref) {
                        // 操作画面の表示
                        showInformation();
                        return true;
                    }
                });

        // メーラープリファレンスコントロールの設定をします。
        ListPreference listMailer = (ListPreference) findPreference(getText(R.string.list_mailer));
        listMailer.setTitle("メーラー：" + sr.getMailerName(sr.getMailer()));
        listMailer
                .setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
                    public boolean onPreferenceChange(Preference preference,
                            Object obj) {
                        String mailer = obj.toString();
                        preference.setTitle("メーラー：" + sr.getMailerName(mailer));

                        // アカウント名プリファレンスコントロールの状態を設定します。
                        setAccountNameEnabled(mailer);
                        return true;
                    }
                });

        // アカウント名プリファレンスコントロールの状態を設定します。
        setAccountNameEnabled(sr.getMailer());

        // アカウント名プリファレンスコントロールの設定をします。
        EditTextPreference editAccountName = (EditTextPreference) findPreference(getText(R.string.edit_account_name));
        editAccountName.setTitle("アカウント名：" + sr.getAccountName());
        editAccountName
                .setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
                    public boolean onPreferenceChange(Preference preference,
                            Object obj) {
                        String accountName = obj.toString();
                        preference.setTitle("アカウント名：" + accountName);
                        return true;
                    }
                });

        // 着信音プリファレンスコントロールの設定をします。
        RingtonePreference ringTone = (RingtonePreference) findPreference(getText(R.string.ringtone_notice_soundname));
        String soundName = sr.getSoundName();
        ringTone.setTitle("着信音：" + (soundName == null ? "" : soundName));
        ringTone.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
            public boolean onPreferenceChange(Preference preference, Object obj) {
                String soundName = "";
                if (obj != null) {
                    soundName = obj.toString();
                }
                preference.setTitle("着信音：" + soundName);
                return true;
            }
        });

        // 着信音の再生時間プリファレンスコントロールの設定をします。
        ListPreference listSoundPlayTime = (ListPreference) findPreference(getText(R.string.list_notice_soundplaytime));
        listSoundPlayTime.setTitle("再生時間："
                + sr.getNoticeSoundPlayTimeText(Long.toString(sr
                        .getNoticeSoundPlayTime())));
        listSoundPlayTime
                .setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
                    public boolean onPreferenceChange(Preference preference,
                            Object obj) {
                        preference.setTitle("再生時間："
                                + sr.getNoticeSoundPlayTimeText(obj.toString()));
                        return true;
                    }
                });

        // バイブレータープリファレンスコントロールの設定をします。
        ListPreference listPattern = (ListPreference) findPreference(getText(R.string.list_notice_vibrateptn));
        listPattern.setTitle("振動パターン：" + sr.getVibratePattern().toString());
        listPattern
                .setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
                    public boolean onPreferenceChange(Preference preference,
                            Object obj) {
                        String vibratePattern = obj.toString();
                        preference.setTitle("振動パターン：" + vibratePattern);

                        // バイブレーターを取得して１回振動させます。
                        sr.getVibrator(vibratePattern, -1);
                        return true;
                    }
                });

        // バイブレーターの振動時間プリファレンスコントロールの設定をします。
        ListPreference listVibrateTime = (ListPreference) findPreference(getText(R.string.list_notice_vibratetime));
        listVibrateTime.setTitle("振動時間："
                + Long.toString(sr.getNoticeVibrateTime()) + "秒");
        listVibrateTime
                .setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
                    public boolean onPreferenceChange(Preference preference,
                            Object obj) {
                        preference.setTitle("振動時間：" + obj.toString() + "秒");
                        return true;
                    }
                });

        // 通知LEDリファレンスコントロールの設定をします。
        CheckBoxPreference checkLed = (CheckBoxPreference) findPreference(getText(R.string.check_notice_ledflag));
        checkLed.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
            public boolean onPreferenceChange(Preference preference, Object obj) {

                boolean ledFlag = Boolean.valueOf(obj.toString());
                if (ledFlag == false) {
                    // 通知をキャンセルします。
                    NotificationManager notificationManager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
                    Notification notification = new Notification();
                    notificationManager.notify(R.string.app_name, notification);
                }
                return true;
            }
        });

        // 通知LED色リファレンスコントロールの設定をします。
        ListPreference listLedColor = (ListPreference) findPreference(getText(R.string.list_notice_ledcolor));
        listLedColor.setTitle("通知LED色：" + sr.getLedColorText(sr.getLedColor()));
        listLedColor
                .setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
                    public boolean onPreferenceChange(Preference preference,
                            Object obj) {
                        String ledColor = obj.toString();
                        preference.setTitle("通知LED色："
                                + sr.getLedColorText(ledColor));
                        return true;
                    }
                });

        // 鳴動待機時間プリファレンスコントロールの設定をします。
        ListPreference listWaitTime = (ListPreference) findPreference(getText(R.string.list_notice_waittime));
        listWaitTime
                .setTitle("鳴動待機時間：" + Long.toString(sr.getWaittime()) + "秒");
        listWaitTime
                .setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
                    public boolean onPreferenceChange(Preference preference,
                            Object obj) {
                        preference.setTitle("鳴動待機時間：" + obj.toString() + "秒");
                        return true;
                    }
                });

        // 未受信メール無視時間の設定をします。
        ListPreference listNewMailSpanTime = (ListPreference) findPreference(getText(R.string.list_newmail_spantime));
        listNewMailSpanTime.setTitle("未受信無視時間："
                + Long.toString(sr.getNewMailSpanTime()) + "秒");
        listNewMailSpanTime
                .setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
                    public boolean onPreferenceChange(Preference preference,
                            Object obj) {
                        preference.setTitle("未受信無視時間：" + obj.toString() + "秒");
                        return true;
                    }
                });

        // SpModeMailWatchService の開始。
        startService(new Intent(this, SpModeMailWatchService.class));

        // インフォメーション表示
        if (sr.getShowInformation()) {
            this.showInformation();
        }
    }

    /**
     * アカウント名プリファレンスコントロールの設定
     */
    private void setAccountNameEnabled(String mailer) {
        // アカウント名プリファレンスコントロールを取得する
        EditTextPreference editAccountName = (EditTextPreference) findPreference(getText(R.string.edit_account_name));

        if (SettingReader.MAILER_SPMODE.equals(mailer)) {
            // SPモードメールの場合は入力不可にする。
            editAccountName.setEnabled(false);
        } else {
            // CommuniCase の場合は入力可能にする。
            editAccountName.setEnabled(true);
        }
    }

    /***
     * インフォメーション画面を表示します。
     */
    private void showInformation() {
        // 操作画面の表示
        Intent i = new Intent(this, InformationActivity.class);
        this.startActivity(i);
    }
}
